yakumo.cinder.v2.quota_set.Manager

Package yakumo :: Package cinder :: Package v2 :: Module quota_set :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for Quota sets in Block Storage API v2

Nested Classes | [hide private]
| resource_class Resource class for Quota sets in Block Storage API v2

Instance Methods | [hide private]
yakumo.cinder.v2.quota_set.Resource |
get(self, project=None, user=None) Get quota set for a project | source code
None |
update(self, project=`'``__UNDEF__``'`, user=`'``__UNDEF__``'`, volumes=`'``__UNDEF__``'`, per_volume_gigabytes=`'``__UNDEF__``'`, snapshots=`'``__UNDEF__``'`, gigabytes=`'``__UNDEF__``'`, backups=`'``__UNDEF__``'`, backup_gigabytes=`'``__UNDEF__``'`) Update quota set for a project | source code
None |
delete(self, project=None, user=None) Delete quota set for a project | source code
yakumo.cinder.v2.quota_set.Resource |
get_default(self, project=None) Get default quota set for a project | source code
Inherited from `base.Manager`: `__init__`, `create`, `find`, `find_one`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``volume``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``create``'``]``
| _json_resource_key = ``'``quota_set``'``
| _url_resource_path = ``'``/os-quota-sets``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_json_resources_key`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### get(self, project=None, user=None) | source code
Get quota set for a project Parameters: `project` (yakumo.project.Resource) - Project (required) `user` (yakumo.user.Resource) - User Returns: yakumo.cinder.v2.quota_set.Resource Resource object Overrides: base.Manager.get

### update(self, project=`'``__UNDEF__``'`, user=`'``__UNDEF__``'`, volumes=`'``__UNDEF__``'`, per_volume_gigabytes=`'``__UNDEF__``'`, snapshots=`'``__UNDEF__``'`, gigabytes=`'``__UNDEF__``'`, backups=`'``__UNDEF__``'`, backup_gigabytes=`'``__UNDEF__``'`) | source code
Update quota set for a project Parameters: `project` (yakumo.project.Resource) - Project object (required) `user` (yakumo.user.Resource) - User object `volumes` (int) - Max number of volumes `per_volume_gigabytes` (int) - Max size of a volume in GB `snapshots` (int) - Max number of snapshots `gigabytes` (int) - Max total size of volumes in GB `backups` (int) - Max number of volume backups `backup_gigabytes` (int) - max total size of volume backup in GB Returns: None

### delete(self, project=None, user=None) | source code
Delete quota set for a project Parameters: `project` (yakumo.project.Resource) - Project `user` (yakumo.user.Resource) - User Returns: None

### get_default(self, project=None) | source code
Get default quota set for a project Parameters: `project` (yakumo.project.Resource) - Project Returns: yakumo.cinder.v2.quota_set.Resource Default quota set

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('volumes', 'volumes', mapper.Noop), ('per
      _volume_gigabytes', 'per_volume_gigabytes', mapper.Noop), ('snapshots'
      , 'snapshots', mapper.Noop), ('gigabytes', 'gigabytes', mapper.Noop),
      ('backups', 'backups', mapper.Noop), ('backup_gigabytes', 'backup_giga
      bytes', mapper.Noop),]